@@ -195,6 +195,11 @@ def urlencode(h):
     """
     return urllib.urlencode(h)
 
+def urlquote(s):
+    """ Call urllib.quote
+    """
+    return urllib.quote(s)
+
 def cgi_escape(s):
     return cgi.escape(s)
 
@@ -324,3 +329,9 @@ def actual_context(context, search="PlominoDocument"):
         return current_context
     else:
         return None
+
+def is_email(email):
+    if re.match("^.+\\@(\\[?)[a-zA-Z0-9\\-\\.]+\\.([a-zA-Z]{2,3}|[0-9]{1,3})(\\]?)$", email) != None:
+        return True
+    else:
+        return False
\ No newline at end of file
